<?php

declare(strict_types=1);

return [
    'twilio' => [
        'sid' => env('NOTIFIER_TWILIO_SID'),
        'token' => env('NOTIFIER_TWILIO_TOKEN'),
        'from' => env('NOTIFIER_TWILIO_FROM'),
    ],
];